@@ -1,4 +1,4 @@
 from .dag import Dag
-from .task import Task
+from .task import Task, Arg
 
 __version__ = "0.5.0"
